@@ -4,21 +4,23 @@ import numpy as np
 import jax.numpy as jnp
 from jax import jit
 
-NAME = 'Feedforward Delay'
+from jaxdsp.param import Param
+from jaxdsp.processors.base import default_param_values
 
 MAX_DELAY_SIZE_SAMPLES = 44_100
 
-def init_params(wet_amount=1.0, delay_samples=6.5):
-    return {
-        'wet_amount': wet_amount,
-        'delay_samples': delay_samples,
-    }
+NAME = 'Feedforward Delay'
+PARAMS = [Param('wet', 1.0), Param('delay_samples', 6.5, 0.0, float(MAX_DELAY_SIZE_SAMPLES))]
+PRESETS = {}
 
 def init_state():
     return {}
 
+def init_params():
+    return default_param_values(PARAMS)
+
 def default_target_params():
-    return init_params(0.5, 6.0)
+    return {'wet': 0.5, 'delay_samples': 6.0}
 
 def tick(carry, x):
     raise 'single-sample tick method not implemented for feedforward delay'
@@ -31,4 +33,4 @@ def tick_buffer(carry, X):
     remainder = delay_samples - jnp.floor(delay_samples)
     X_linear_interp = (1 - remainder) * X + remainder * jnp.concatenate([jnp.array([0]), X[:X.size - 1]])
     Y = jnp.where(jnp.arange(X.size) >= delay_samples, jnp.roll(X_linear_interp, delay_samples.astype('int32')), 0)
-    return carry, X * (1 - params['wet_amount']) + Y * params['wet_amount']
+    return carry, X * (1 - params['wet']) + Y * params['wet']
